==> mutt_0.88.orig.tar.gz: mutt-0.88/send.h <==
/*
 * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
 * 
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */ 

ADDRESS *mutt_default_from (void);
ADDRESS *mutt_remove_duplicates (ADDRESS *);

BODY *mutt_make_attach (const char *);
BODY *mutt_make_multipart (BODY *);

char *mutt_generate_boundary (void);

void mutt_choose_fcc (char *, size_t, ENVELOPE *);
void mutt_edit_file (const char *, const char *);
void mutt_edit_headers (const char *, const char *, ENVELOPE **, char *, size_t);
void mutt_set_encoding (BODY *a, CONTENT *info);
void mutt_update_encoding (BODY *a);

int is_local_site (ADDRESS *);
int mutt_builtin_editor (const char *, ENVELOPE **, HEADER *);
int mutt_get_postponed (HEADER *, HEADER **);
int mutt_send_menu (HEADER *, char *, size_t, HEADER *);
int mutt_send_message (HEADER *, const char *);
int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int);
int mutt_write_mime_body (BODY *, FILE *);
int mutt_write_mime_header (BODY *, FILE *);
int mutt_write_rfc822_header (FILE *, ENVELOPE *, BODY *, int);

#ifdef _PGPPATH
BODY *pgp_sign_message (BODY *);
BODY *pgp_encrypt_message (BODY *, char *, int);
char *pgp_findKeys (ADDRESS *, ADDRESS *, ADDRESS *);
#endif

==> mutt-0.89.tar.gz: mutt-0.89/send.h <==
/*
 * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
 * 
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */ 

ADDRESS *mutt_default_from (void);
ADDRESS *mutt_remove_duplicates (ADDRESS *);

BODY *mutt_make_attach (const char *);
BODY *mutt_make_multipart (BODY *);

char *mutt_generate_boundary (void);

void mutt_edit_file (const char *, const char *);
void mutt_edit_headers (const char *, const char *, HEADER *, char *, size_t);
/* void mutt_set_encoding (BODY *a, CONTENT *info); */
void mutt_update_encoding (BODY *a);

int mutt_builtin_editor (const char *, HEADER *, HEADER *);
int mutt_get_postponed (HEADER *, HEADER **);
int mutt_send_menu (HEADER *, char *, size_t, HEADER *);
int mutt_send_message (HEADER *, const char *);
int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int);
int mutt_write_mime_body (BODY *, FILE *);
int mutt_write_mime_header (BODY *, FILE *);
int mutt_write_rfc822_header (FILE *, ENVELOPE *, BODY *, int);
